---
sidebar_label: alias
title: soil.alias
---

This package contains calls for soil alias data structures

#### alias

```python
def alias(name: str,
          data_ref: DataStructure,
          roles: Optional[List[str]] = None) -> None
```

Set an alias to a data reference

